@@ -37,7 +37,6 @@ class LBaaSController(object):
     def __init__(self, logger, driver, json_msg):
         self.logger = logger
         self.driver = driver
-        self.logger.debug("Entered LBaaSController")
         self.msg = json_msg
 
     def run(self):
@@ -51,7 +50,6 @@ class LBaaSController(object):
             return self.msg
 
         action = self.msg[self.ACTION_FIELD].upper()
-        self.logger.info("Requested action: %s" % action)
 
         try:
             if action == 'UPDATE':
@@ -173,24 +171,60 @@ class LBaaSController(object):
                 self.msg[self.RESPONSE_FIELD] = self.RESPONSE_FAILURE
                 return self.msg
 
+            if 'monitor' in current_lb:
+                monitor = current_lb['monitor']
+                for opt in ['type', 'delay', 'timeout', 'attempts']:
+                    if opt not in monitor:
+                        return BadRequest("Missing monitor value '%s'" %
+                                          opt).to_json()
+                if 'path' not in monitor:
+                    monitor['path'] = '/'
+
+                try:
+                    self.driver.add_monitor(current_lb['protocol'],
+                                            monitor['type'],
+                                            monitor['delay'],
+                                            monitor['timeout'],
+                                            monitor['attempts'],
+                                            monitor['path'])
+                except NotImplementedError:
+                    self.logger.error(
+                        "Selected driver does not support adding healthchecks."
+                    )
+                    self.msg[self.RESPONSE_FIELD] = self.RESPONSE_FAILURE
+                    return self.msg
+                except Exception as e:
+                    self.logger.error(
+                        "Selected driver failed adding healthchecks: %s, %s" %
+                        (e.__class__, e)
+                    )
+                    self.msg[self.RESPONSE_FIELD] = self.RESPONSE_FAILURE
+                    return self.msg
+
             for lb_node in current_lb['nodes']:
-                port, address, weight = None, None, None
+                port, address, node_id, weight = None, None, None, None
 
                 if 'port' in lb_node:
                     port = lb_node['port']
                 else:
-                    return BadRequest("Missing 'port' element.").to_json()
+                    return BadRequest("Missing node 'port'").to_json()
 
                 if 'address' in lb_node:
                     address = lb_node['address']
                 else:
-                    return BadRequest("Missing 'address' element.").to_json()
+                    return BadRequest("Missing node 'address'").to_json()
+
+                if 'id' in lb_node and lb_node['id'] != '':
+                    node_id = lb_node['id']
+                else:
+                    return BadRequest("Missing node 'id'").to_json()
 
                 if 'weight' in lb_node:
                     weight = lb_node['weight']
 
                 try:
                     self.driver.add_server(current_lb['protocol'],
+                                           node_id,
                                            address,
                                            port,
                                            weight)
@@ -348,7 +382,7 @@ class LBaaSController(object):
 
         try:
             # TODO: Do something with the returned statistics
-            self.driver.get_stats(protocol=None)
+            stats = self.driver.get_stats()
         except NotImplementedError:
             error = "Selected driver does not support STATS action."
             self.logger.error(error)
@@ -363,5 +397,11 @@ class LBaaSController(object):
             self.msg[self.RESPONSE_FIELD] = self.RESPONSE_FAILURE
             self.msg[self.ERROR_FIELD] = str(e)
         else:
+            node_status = stats.node_status_map()
+            self.msg['nodes'] = []
+            for node in node_status.keys():
+                self.msg['nodes'].append({'id': node,
+                                          'status': node_status[node]})
             self.msg[self.RESPONSE_FIELD] = self.RESPONSE_SUCCESS
+
         return self.msg
